@@ -67,7 +67,8 @@ class GraphQLClient:
         op = Operation(Query)
         bills = op.all_bills()
         bills.id()
-        bills.bill_title()
+        bills.name()
+        bills.bill_number()
         minutes = bills.be_discussed_by_minutes()
         minutes.id()
         minutes.minutes_number()
